==> ghemical-0.80.tar.gz: ghemical-0.80/src/common/filetrans.h <==
// FILETRANS.H:   Handle import/export through use of the OELib external lib.
//
// Copyright (C) 2000 Geoffrey Hutchison

// This program is free software; you can redistribute it and/or modify it
// under the terms of the license (GNU GPL) which comes with this package.

/*################################################################################################*/

#include "config.h"

#ifndef FILETRANS_H
#define FILETRANS_H

/*################################################################################################*/

#include "mm1mdl.h"

#include <string>
#include <vector>
#include <iostream>
#include <fstream>
using namespace std;

/*################################################################################################*/

typedef struct {
  mm1_atom * atmr;
  OEAtom * oea;
} atom_name_tag;

typedef struct {
  string   format;
  unsigned int offset;
} format_record;

class file_trans
{
        private:

  vector<format_record> imports;
  vector<format_record> exports;
  
  int name_tag_count;
  atom_name_tag * tagtab;
  mm1_mdl * mdl; OEMol * oem;
  iter_mm1al itb; iter_mm1al ite;
  
  	public:
  
  file_trans();
  virtual ~file_trans();
  
  // these expect to be passed the filename to pick the file format
  int Import(const char *, istream &, ostream &);
  int Export(const char *, istream &, ostream &);

  // these check whether the format picked by the filename are valid
  bool CanImport(const char *);
  bool CanExport(const char *);

  // Get a listing of the number of valid import/export types
  unsigned int NumImports() { return imports.size(); }
  unsigned int NumExports() { return exports.size(); }

  // Get the description associated with this type
  string GetExportDescription(unsigned int);
  string GetImportDescription(unsigned int);
  
  // These take the unsigned int as a format specifier
  int Import(const char *, unsigned int, istream &, ostream &);
  int Export(const char *, unsigned int, istream &, ostream &);
  
  	// some OELib compatibility methods:
	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	
  /// This takes a pair of atom list iterators, and copies all atoms/bonds in this range to OEMol.
  OEMol * Copy(mm1_mdl *, iter_mm1al, iter_mm1al);
  
  /// This will copy a molecule (defined by the index) to OEMol.
  OEMol * CopyMolecule(mm1_mdl *, int);
  
  /// This will copy everything in this model to OEMol.
  OEMol * CopyAll(mm1_mdl *);
  
  /// This will syncronize the model and the OEMol.
  void Synchronize(void);
  
};

/*################################################################################################*/

#endif	// FILETRANS_H

// eof

==> ghemical_0.82.orig.tar.gz: ghemical-0.82.orig/src/common/filetrans.h <==
// FILETRANS.H:   Handle import/export through use of the Babel external lib.
//
// Copyright (C) 2000 Geoffrey Hutchison

// This program is free software; you can redistribute it and/or modify it
// under the terms of the license (GNU GPL) which comes with this package.

/*################################################################################################*/

#include "config.h"

#ifndef FILETRANS_H
#define FILETRANS_H

/*################################################################################################*/

#include "mm1mdl.h"

#include <string>
#include <vector>
#include <iostream>
#include <fstream>
using namespace std;

/*################################################################################################*/

typedef struct {
  mm1_atom * atmr;
  OBAtom * oba;
} atom_name_tag;

typedef struct {
  string   format;
  unsigned int offset;
} format_record;

class file_trans
{
        private:

  vector<format_record> imports;
  vector<format_record> exports;
  
  int name_tag_count;
  atom_name_tag * tagtab;
  mm1_mdl * mdl; OBMol * obm;
  iter_mm1al itb; iter_mm1al ite;
  
  	public:
  
  file_trans();
  virtual ~file_trans();
  
  // these expect to be passed the filename to pick the file format
  int Import(const char *, istream &, ostream &);
  int Export(const char *, istream &, ostream &);

  // these check whether the format picked by the filename are valid
  bool CanImport(const char *);
  bool CanExport(const char *);

  // Get a listing of the number of valid import/export types
  unsigned int NumImports() { return imports.size(); }
  unsigned int NumExports() { return exports.size(); }

  // Get the description associated with this type
  string GetExportDescription(unsigned int);
  string GetImportDescription(unsigned int);
  
  // These take the unsigned int as a format specifier
  int Import(const char *, unsigned int, istream &, ostream &);
  int Export(const char *, unsigned int, istream &, ostream &);
  
  	// some Babel compatibility methods:
	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	
  /// This takes a pair of atom list iterators, and copies all atoms/bonds in this range to OBMol.
  OBMol * Copy(mm1_mdl *, iter_mm1al, iter_mm1al);
  
  /// This will copy a molecule (defined by the index) to OBMol.
  OBMol * CopyMolecule(mm1_mdl *, int);
  
  /// This will copy everything in this model to OBMol.
  OBMol * CopyAll(mm1_mdl *);
  
  /// This will syncronize the model and the OBMol.
  void Synchronize(void);
  
};

/*################################################################################################*/

#endif	// FILETRANS_H

// eof
